@@ -3,12 +3,9 @@ from termcolor import colored
 from re import search, IGNORECASE
 
 from Nemesis.lib.Globals import Color
-from Nemesis.lib.Globals import base64char, hexchar, dom_sources_regex, dom_sinks_regex
-from Nemesis.lib.Globals import url_regex, url_regex_without_netloc, subdomain_regex, path_regex, single_path_regex
-from Nemesis.lib.Globals import web_services_regex, custom_regex_sensitive, custom_regex_insensitive, experimental_path_regex
-
-from warnings import warn
-warn("Experimental path regex is experimental and might generate false positives")
+from Nemesis.lib.Globals import base64char, hexchar, dom_sources_regex, dom_sinks_regex, extractor
+from Nemesis.lib.Globals import subdomain_regex, path_regex, single_path_regex, experimental_path_regex
+from Nemesis.lib.Globals import web_services_regex, custom_regex_sensitive, custom_regex_insensitive
 
 def banner():
     b = '\x1b[1m\x1b[31m    _   __                         _     \n   / | / /__  ____ ___  ___  _____(_)____\n  /  |/ / _ \\/ __ `__ \\/ _ \\/ ___/ / ___/\n / /|  /  __/ / / / / /  __(__  ) (__  ) \n/_/ |_/\\___/_/ /_/ /_/\\___/____/_/____/  \n                                         \n\x1b[0m'
@@ -16,6 +13,10 @@ def banner():
 
 def starter(argv):
     from sys import stdin
+    from warnings import warn
+    print("DEBUG INFORMATION")
+    warn("Experimental path regex is experimental and might generate false positives")
+    print("Pretty print match is disabled")
     if argv.banner:
         banner()
         exit()
@@ -83,14 +84,15 @@ def url_extract(line: str) -> tuple:
         if search(web_service, line):
             mline = search(web_service, line).group()
             output_list = (mline, 'web_services_match')
-    if search(url_regex, line):
-        mline = search(url_regex, line).group()
-        output_list = (mline, 'url_match')
-    elif search(url_regex_without_netloc, line):
-        mline = search(url_regex_without_netloc, line).group()
-        output_list = (mline, 'url_match_without_netloc')
-        #if unender(unurler(line), '/') == self.argv.domain:
-        #    return ()
+    #if search(url_regex, line):
+    #    mline = search(url_regex, line).group()
+    #    output_list = (mline, 'url_match')
+    #elif search(url_regex_without_netloc, line):
+    #    mline = search(url_regex_without_netloc, line).group()
+    #    output_list = (mline, 'url_match_without_netloc')
+    if extractor.has_urls(line):
+        mline = extractor.find_urls(line)[0]
+        output_list = (mline, 'url_match') if '://' in mline or 'www' in mline or '/' in mline or '?' else ()
     return output_list
 
 def path_extract(line: str) -> tuple:
@@ -128,23 +130,28 @@ def custom_extract(line: str) -> tuple:
             output_list = (mline, 'custom_regex')
     return output_list
 
-def link_extract(line: str, domain = "") -> tuple:
+def link_extract(line: str, domain = "", already = False) -> tuple:
     # rename output_list to output_tuple
     output_list = ()
     if not line or line.startswith('#'):
         return output_list
+    if already:
+        return (line, 'link_match')
     for web_service in web_services_regex:
         if search(web_service, line):
             mline = search(web_service, line).group()
             output_list = (mline, 'web_services_match')
             return output_list
     # url_regex over subdomain_regex, might supress
-    if search(url_regex, line):
-        mline = search(url_regex, line).group()
-        output_list = (mline, 'url_match')
-    elif search(url_regex_without_netloc, line):
-        mline = search(url_regex_without_netloc, line).group()
-        output_list = (mline, 'url_match_without_netloc')
+    if extractor.has_urls(line):
+        mline = extractor.find_urls(line)[0]
+        output_list = (mline, 'url_match') if '://' in mline or 'www' in mline else ()
+    #if search(url_regex, line):
+    #    mline = search(url_regex, line).group()
+    #    output_list = (mline, 'url_match')
+    #elif search(url_regex_without_netloc, line):
+    #    mline = search(url_regex_without_netloc, line).group()
+    #    output_list = (mline, 'url_match_without_netloc')
     elif search(path_regex, line):
         mline = search(path_regex, line).group()
         output_list = (mline, 'path_match')
@@ -155,15 +162,20 @@ def link_extract(line: str, domain = "") -> tuple:
         mline = search(experimental_path_regex, 'experimental_path_match')
         output_list = (mline, 'experimental_path_match')
     elif domain and search(subdomain_regex(domain), line):
-        mline = search(subdomain_regex(domain).group(), line)
+        mline = search(subdomain_regex(domain), line).group()
         if not mline == domain:
             output_list = (mline, 'subdomain_match')
     return output_list
 
-def pretty_print(line: str, match_type_tuple: tuple):
-    if not match_type_tuple: return
-    match, match_type = match_type_tuple
-    match_type = match_type.split('_match')[0].replace('_', ' ')
+def pretty_print(line: str, match: str, match_type: str = ""):
+    if not match:
+        return None
+    match_type = ""
+    if match_type:
+        match_type = match_type.split('_match')[0].replace('_', ' ')
     split_beginning, split_end = line.split(match)[0], line.split(match)[-1]
     colored_line = split_beginning + colored(match, color='red', attrs=['bold']) + split_end
-    print(f"{Color.good} Found: {colored_line} (Match: {match_type})")
+    if match_type:
+        print(f"{Color.good} Found: {colored_line} (Match: {match_type})")
+    else:
+        print(f"{Color.good} Found: {colored_line}")
