@@ -1,9 +1,13 @@
+from urlextract import URLExtract
+
 from Nemesis.lib.Color import Color
 
 # General
+
 # Matches url but not direct path
-url_regex = "((http|https)://)[a-zA-Z0-9\./?:@-_=]+\.([a-zA-Z]){2,6}([a-zA-Z0-9\.\&\/\?\:@\-_=#])*"
-url_regex_without_netloc = "((http|https)://)?[a-zA-Z0-9\./?:@-_=]+\.([a-zA-Z]){2,6}([a-zA-Z0-9\.\&\/\?\:@\-_=#])*"
+#url_regex = "((http|https)://)[a-zA-Z0-9\./?:@-_=]+\.([a-zA-Z]){2,6}([a-zA-Z0-9\.\&\/\?\:@\-_=#])*"
+#url_regex_without_netloc = "((http|https)://)?[a-zA-Z0-9\./?:@-_=]+\.([a-zA-Z]){2,6}([a-zA-Z0-9\.\&\/\?\:@\-_=#])*"
+
 single_path_regex = """('|"|\(|\))(\/){1}[a-zA-Z0-9-_]+(/)?('|"|\(|\))""" #(hi/) or "hi/"
 path_regex = "([a-zA-Z0-9]+\.[a-zA-Z0-9]{3,6})?\/(([0-9a-zA-Z+.-]+)([\/&| ])){1,30}([a-zA-Z0-9]+(\.[a-zA-Z0-9]*)?)?(\?|;)?([a-zA-Z\[\]&=]*)?"
 experimental_path_regex = "/?\w+(?:/\w+)*\?\w+=\w+(?:&\w+=\w+)*|(?:\w+(?:/\w+){2,}/?|\w+(?:/\w+)+/|/\w+/)(?:&\w+=\w+)*"
@@ -70,3 +74,4 @@ web_services_regex = [
 hexchar = "1234567890abcdefABCDEF"
 base64char = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="
 Color = Color()
+extractor = URLExtract()
